@@ -12,6 +12,11 @@ option 'message' => (
 
 subcommand yell => 'MyTest::Class::Basic::Yell';
 
+subcommand whisper => sub {
+    my ($self) = @_;
+    print lc $self->message, "\n";
+};
+
 sub run {
     my ($self) = @_;
     print $self->message, "\n";
